/**
* @file
* @brief    boxplus lightweight window engine on mouse-over
* @author   Levente Hunyadi
* @version  1.4.2
* @remarks  Copyright (C) 2009-2010 Levente Hunyadi
* @remarks  Licensed under GNU/GPLv3, see http://www.gnu.org/licenses/gpl-3.0.html
* @see      http://hunyadi.info.hu/projects/boxplus
*/

#boxplus-dialog {
position:absolute;
width:100px;
height:100px;
margin:0;
border:thin solid black;
padding:5px;
overflow:hidden;
background:white url(loading.gif) no-repeat scroll center center;
z-index:8;
}

#boxplus-dialog.hide {
visibility:hidden;
}

#boxplus-viewer {
margin:0;
border:0 none transparent;
padding:0;
background:white url(loading.gif) no-repeat scroll center center;
}

#boxplus-viewer.hide {
visibility:hidden;
}

#boxplus-caption {
margin:5px 0 5px 0;
padding:0;
}

#boxplus-caption.hide {
visibility:hidden;
}

#boxplus-caption .title {
font-weight:bold;
}
