/**
* @file
* @brief    boxplus mouse-over image caption stylesheet
* @author   Levente Hunyadi
* @version  1.4.2
* @remarks  Copyright (C) 2009-2010 Levente Hunyadi
* @remarks  Licensed under GNU/GPLv3, see http://www.gnu.org/licenses/gpl-3.0.html
* @see      http://hunyadi.info.hu/projects/boxplus
*/

div.boxplus-imagecaption {
display:block !important;
position:absolute !important;
left:0 !important;
right:0 !important;
margin:0 !important;
text-align:center !important;
visibility:visible !important;
z-index:1;
}

/* caption that displays over image */
div.boxplus-imagecaption.boxplus-overlaycaption {
background-color:black !important;  /* fall-back setting, overridden for IE */
background-color:rgba(0,0,0,0.6) !important;  /* overridden for IE */
color:white !important;
height:30% !important;
bottom:0 !important;
padding:4px !important;
overflow:hidden !important;
}

/* caption that displays below image */
div.boxplus-imagecaption.boxplus-figurecaption {
height:60px !important;
bottom:-60px !important;
padding:0 !important;
overflow:auto !important;
}

div.boxplus-imagecaption.boxplus-hidden {
visibility:hidden !important;
}

.boxplus-hidden div.boxplus-imagecaption {
visibility:hidden !important;
}

/* buttons inside image caption */
div.boxplus-imagecaption > div.boxplus-buttons {
display:block !important;
}

div.boxplus-imagecaption > div.boxplus-buttons > div {
background:transparent none no-repeat center center !important;
display:inline-block !important;
height:16px !important;
width:16px !important;
margin:2px !important;
cursor:pointer !important;
}

div.boxplus-imagecaption > div.boxplus-buttons > div.boxplus-metadata {
background-image:url(camera.png) !important;
}

div.boxplus-imagecaption > div.boxplus-buttons > div.boxplus-download {
background-image:url(disk.png) !important;
}

div.boxplus-container {
display:block !important;
position:absolute !important;
visibility:hidden !important;
}