<script language="javascript">
<!-- 
    setTimeout("cyend_redirect();", 1000);
//--> 
</script>
<?php $params = \Joomla\CMS\Factory::getConfig(); ?>
<div style="text-align: center;" class="alert alert-info">
    <p>processing on site:</p>
    <p><b><?php echo $params->get('sitename'); ?></b></p>
    <p><img src="../media/kainotomo/images/processing.gif" border="0" alt=""/></p>
    <p>please wait...</p>
</div>
