DROP TABLE IF EXISTS `#__spstgsrv_log`;
CREATE TABLE IF NOT EXISTS `#__spstgsrv_log` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `package_name` varchar(255) NOT NULL DEFAULT '',
  `package_path` varchar(255) NOT NULL COMMENT 'path where the package is located',
  `message` mediumtext NOT NULL COMMENT 'Event Description',
  `ip` varchar(50) NOT NULL COMMENT 'Manager IP',
  `result` tinyint(4) NOT NULL COMMENT '1 - Success, 0 - Failed',
  `created` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  `created_by` int(10) unsigned NOT NULL DEFAULT '0',
  `version` varchar(255) NOT NULL,
  PRIMARY KEY (`id`),
  KEY `idx_createdby` (`created_by`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1;

DROP TABLE IF EXISTS `#__spstgsrv_backups`;
CREATE TABLE IF NOT EXISTS `#__spstgsrv_backups` (
  `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `filename` varchar(255) NOT NULL DEFAULT '',
  `mdate` int(11) NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;
