.icon-48-generic {
	background: url(../images/jSecurelite_icon_48x48.png) no-repeat !important;
	text-indent: 10px; 
}
.icon-32-login{
	background: url(../images/login.gif) no-repeat !important;
	text-indent: 10px; 
}
table.admintable td.key, table.admintable td.paramlist_key {
	width:200px !important;
}

.btns { 
display:inline-block; 
padding: 10px 14px 10px;
}
.btns.blue-pill {
  background-color: #a5b8da;
  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #a5b8da), color-stop(100%, #7089b3));
  background-image: -webkit-linear-gradient(top, #a5b8da, #7089b3);
  background-image: -moz-linear-gradient(top, #a5b8da, #7089b3);
  background-image: -ms-linear-gradient(top, #a5b8da, #7089b3);
  background-image: -o-linear-gradient(top, #a5b8da, #7089b3);
  background-image: linear-gradient(top, #a5b8da, #7089b3);
  border-top: 1px solid #758fba;
  border-right: 1px solid #6c84ab;
  border-bottom: 1px solid #5c6f91;
  border-left: 1px solid #6c84ab;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 0 0 #aec3e5, 0 1px 3px rgba(51,51,51,0.7);
  -ms-box-shadow: inset 0 1px 0 0 #aec3e5, 0 1px 3px rgba(51,51,51,0.7);
  -o-box-shadow: inset 0 1px 0 0 #aec3e5, 0 1px 3px rgba(51,51,51,0.7);
  box-shadow: inset 0 1px 0 0 #aec3e5, 0 1px 3px rgba(51,51,51,0.7);
  color: #fff;
  font: bold 11px/1 Arial,Helvetica,sans-serif;
  text-align: center;
  text-shadow: 0 -1px 1px #64799e;
   }

.btns.blue-pill:hover {
    background-color: #9badcc;
    background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #9badcc), color-stop(100%, #687fa6));
    background-image: -webkit-linear-gradient(top, #9badcc, #687fa6);
    background-image: -moz-linear-gradient(top, #9badcc, #687fa6);
    background-image: -ms-linear-gradient(top, #9badcc, #687fa6);
    background-image: -o-linear-gradient(top, #9badcc, #687fa6);
    background-image: linear-gradient(top, #9badcc, #687fa6);
    border-top: 1px solid #6d86ad;
    border-right: 1px solid #647a9e;
    border-bottom: 1px solid #546685;
    border-left: 1px solid #647a9e;
    -webkit-box-shadow: inset 0 1px 0 0 #a5b9d9;
    box-shadow: inset 0 1px 0 0 #a5b9d9;
    cursor: pointer; }

.btns.blue-pill:active {
    border: 1px solid #546685;
    -webkit-box-shadow: inset 0 0 8px 2px #7e8da6, 0 1px 0 0 #eeeeee;
    box-shadow: inset 0 0 8px 2px #7e8da6, 0 1px 0 0 #eeeeee; }