<?php
/**
 * @package    Joomla.Libraries
 *
 * @copyright  Copyright (C) 2005 - 2016 Open Source Matters, Inc. All rights reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE
 */

JLoader::registerAlias('JRegistry',           '\\Joomla\\Registry\\Registry');
JLoader::registerAlias('JRegistryFormat',     '\\Joomla\\Registry\\AbstractRegistryFormat');
JLoader::registerAlias('JRegistryFormatIni',  '\\Joomla\\Registry\\Format\\Ini');
JLoader::registerAlias('JRegistryFormatJson', '\\Joomla\\Registry\\Format\\Json');
JLoader::registerAlias('JRegistryFormatPhp',  '\\Joomla\\Registry\\Format\\Php');
JLoader::registerAlias('JRegistryFormatXml',  '\\Joomla\\Registry\\Format\\Xml');
JLoader::registerAlias('JStringInflector',    '\\Joomla\\String\\Inflector');
JLoader::registerAlias('JStringNormalise',    '\\Joomla\\String\\Normalise');
