<?php

/**
 * @package		SP Staging
 * @subpackage	Components
 * @copyright	KAINOTOMO PH LTD - All rights reserved.
 * @author		KAINOTOMO PH LTD
 * @link		https://www.kainotomo.com
 * @license GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
*/

// no direct access
defined('_JEXEC') or die;

jimport('joomla.application.component.controller');

class SPStgSrvControllerInstaller extends JControllerLegacy {

    public function __construct($config = array()) {
        parent::__construct($config);

        $this->registerTask('install', 'install');
    }

    public function install() {
        echo "NORMAL HTTP TASK";
        return;
    }

    public function my() {
        echo 'adsf';
    }

}

?>
