<?php

// autoload_psr4.php @generated by Composer

$vendorDir = dirname(dirname(__FILE__));
$baseDir = dirname(dirname($vendorDir));

return array(
    'Symfony\\Polyfill\\Util\\' => array($vendorDir . '/symfony/polyfill-util'),
    'Symfony\\Polyfill\\Php56\\' => array($vendorDir . '/symfony/polyfill-php56'),
    'Symfony\\Component\\Yaml\\' => array($vendorDir . '/symfony/yaml'),
    'Joomla\\Utilities\\Tests\\' => array($vendorDir . '/joomla/utilities/Tests'),
    'Joomla\\Utilities\\' => array($vendorDir . '/joomla/utilities/src'),
    'Joomla\\Uri\\Tests\\' => array($vendorDir . '/joomla/uri/Tests'),
    'Joomla\\Uri\\' => array($vendorDir . '/joomla/uri/src'),
    'Joomla\\String\\Tests\\' => array($vendorDir . '/joomla/string/Tests'),
    'Joomla\\String\\' => array($vendorDir . '/joomla/string/src'),
    'Joomla\\Registry\\Tests\\' => array($vendorDir . '/joomla/registry/Tests'),
    'Joomla\\Registry\\' => array($vendorDir . '/joomla/registry/src'),
    'Joomla\\Input\\Tests\\' => array($vendorDir . '/joomla/input/Tests'),
    'Joomla\\Input\\' => array($vendorDir . '/joomla/input/src'),
    'Joomla\\Filter\\Tests\\' => array($vendorDir . '/joomla/filter/Tests'),
    'Joomla\\Filter\\' => array($vendorDir . '/joomla/filter/src'),
    'Joomla\\Event\\Tests\\' => array($vendorDir . '/joomla/event/Tests'),
    'Joomla\\Event\\' => array($vendorDir . '/joomla/event/src'),
    'Joomla\\DI\\Tests\\' => array($vendorDir . '/joomla/di/Tests'),
    'Joomla\\DI\\' => array($vendorDir . '/joomla/di/src'),
    'Joomla\\Application\\Tests\\' => array($vendorDir . '/joomla/application/Tests'),
    'Joomla\\Application\\' => array($vendorDir . '/joomla/application/src'),
);
