/*!
* @file
* @brief    boxplus: a lightweight pop-up window engine shipped with sigplus
* @author   Levente Hunyadi
* @version  1.4.2
* @remarks  Copyright (C) 2009-2010 Levente Hunyadi
* @remarks  Licensed under GNU/GPLv3, see http://www.gnu.org/licenses/gpl-3.0.html
* @see      http://hunyadi.info.hu/projects/boxplus
*/

#boxplus .boxplus-dialog {
border:0 none transparent;
}

#boxplus .boxplus-dialog .boxplus-main {
margin:30px;
padding:0px;
background-color:transparent;
}

#boxplus .boxplus-dialog .boxplus-sideways {
right:20px;
top:20px;
bottom:20px;
}

/* dialog frame */
#boxplus .boxplus-dialog .boxplus-m {
position:absolute;
top:20px;
bottom:20px;
left:20px;
right:20px;
}

#boxplus .boxplus-dialog .boxplus-m.boxplus-hidden {
visibility:visible;  /* always show, IE does not support inherit */
}

#boxplus .boxplus-dialog.boxplus-hidden .boxplus-m.boxplus-hidden {
visibility:hidden;
}

#boxplus .boxplus-dialog .boxplus-t,
#boxplus .boxplus-dialog .boxplus-b {
position:absolute;
height:21px;
left:21px;
right:21px;
}

#boxplus .boxplus-dialog .boxplus-t {
top:0;
background:transparent url(prettyphoto/top.png) repeat-x scroll left top;
}

#boxplus .boxplus-dialog .boxplus-b {
bottom:0;
background:transparent url(prettyphoto/bottom.png) repeat-x scroll left bottom;
}

#boxplus .boxplus-dialog .boxplus-l,
#boxplus .boxplus-dialog .boxplus-r {
position:absolute;
width:21px;
top:20px;
bottom:20px;
}

#boxplus .boxplus-dialog .boxplus-l {
left:0;
background:transparent url(prettyphoto/left.png) repeat-y scroll left top;
}

#boxplus .boxplus-dialog .boxplus-r {
right:0;
background:transparent url(prettyphoto/right.png) repeat-y scroll right top;
}

#boxplus .boxplus-dialog .boxplus-lt,
#boxplus .boxplus-dialog .boxplus-rt,
#boxplus .boxplus-dialog .boxplus-lb,
#boxplus .boxplus-dialog .boxplus-rb {
position:absolute;
width:21px;
height:20px;
}

#boxplus .boxplus-dialog .boxplus-lt {
top:0;
left:0;
background:transparent url(prettyphoto/sprite.png) no-repeat scroll left top;
}

#boxplus .boxplus-dialog .boxplus-rt {
top:0;
right:0;
background:transparent url(prettyphoto/sprite.png) no-repeat scroll right top;
}

#boxplus .boxplus-dialog .boxplus-lb {
bottom:0;
left:0;
background:transparent url(prettyphoto/sprite.png) no-repeat scroll left bottom;
}

#boxplus .boxplus-dialog .boxplus-rb {
bottom:0;
right:0;
background:transparent url(prettyphoto/sprite.png) no-repeat scroll right bottom;
}