<?php
class JSecureliteConfig {
	public $publish = '1';
	public $key = '9aa899065931bc25845a0defce55277e';
	public $passkeytype = 'url';
	public $options = '0';
	public $custom_path = 'plugins/system/jsecurelite/404.html';
}