CREATE TABLE IF NOT EXISTS `#__smartformer_data` (
				`id` int(11) NOT NULL AUTO_INCREMENT,
				`form_id` int(11) NOT NULL DEFAULT '0',
				`datetime` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
				`data` text NOT NULL,
				`rand` varchar(20) NOT NULL DEFAULT '',
				`hash` varchar(32) NOT NULL,
				`status` tinyint(3) unsigned NOT NULL DEFAULT '1',
				PRIMARY KEY (`id`)
		) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=2 ;


CREATE TABLE IF NOT EXISTS `#__smartformer_settings` (
				`id` int(11) NOT NULL AUTO_INCREMENT,
				`type` tinyint(4) NOT NULL DEFAULT '0',
				`variable` varchar(50) NOT NULL DEFAULT '',
				`default` varchar(255) NOT NULL DEFAULT '',
				`value` varchar(255) NOT NULL DEFAULT '',
				PRIMARY KEY (`id`)
		) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=36 ;

		

CREATE TABLE IF NOT EXISTS `#__smartformer_forms` (
				`id` int(11) NOT NULL AUTO_INCREMENT,
				`name` text NOT NULL,
				`status` tinyint(4) NOT NULL DEFAULT '0',
				`data1` longtext NOT NULL,
				`data2` longtext NOT NULL,
				`data3` longtext NOT NULL,
				`data4` longtext NOT NULL,
				`data5` longtext NOT NULL,
				`data6` longtext NOT NULL,
				`data7` longtext NOT NULL,
				`data8` longtext NOT NULL,
				`data9` longtext NOT NULL,
				`data10` longtext NOT NULL,
				`element_to_page` text NOT NULL,
				`checked_out` tinyint(4) NOT NULL DEFAULT '0',
				`checked_out_time` datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
				`editor` varchar(50) NOT NULL DEFAULT '',
				`groups` text NOT NULL,
				`css_list` text NOT NULL,
				`js_list` text NOT NULL,
				`php_list` text NOT NULL,
				`filter` text NOT NULL,
				`enable_notif` tinyint(4) NOT NULL DEFAULT '0',
				`email_format` tinyint(4) NOT NULL DEFAULT '2',
				`fromname` varchar(255) NOT NULL DEFAULT '',
				`fromemail` varchar(255) NOT NULL DEFAULT '',
				`subject` varchar(255) NOT NULL DEFAULT '',
				`cc` varchar(255) NOT NULL DEFAULT '',
				`bcc` varchar(255) NOT NULL DEFAULT '',
				`message` text NOT NULL,
				`admin_template` text NOT NULL,
				PRIMARY KEY (`id`)
		) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=10 ;		