<script language="javascript">
<!-- 
    setTimeout("postMessage();", 1000);
//--> 
    postMessage = function() {

        message = 'success';
        manager_url = document.getElementById('manager_url').value;
        parent.postMessage(message, manager_url);

    };
</script>
<div style="text-align: center;" class="alert alert-success">
    <p><b><?php echo JText::_('COM_SPSTGSRV_INSTALL_SUCCESS'); ?></b></p>    
</div>
<input type="hidden" id="manager_url" value="<?php echo JComponentHelper::getParams('com_spstgsrv')->get('package_path'); ?>" />
