/**
 * @copyright	Copyright (C) 2005 - 2020 Open Source Matters, Inc. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

div.imgOutline {
	float: right;
	border-left: 0 solid #f0f0f0;
	border-right: 1px solid #f0f0f0;
}
