<?php
/**
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

// No direct access
defined('_JEXEC') or die;

jimport('joomla.application.component.controller');

/**
 * Content Component Controller
 *
 * @package		Joomla.Site
 * @subpackage	com_content
 * @since		1.5
 */
class SPStgSrvController extends JControllerLegacy
{
	public function display($cachable = false, $urlparams = false)
	{
		$vName	= JRequest::getCmd('view', 'installer');
		JRequest::setVar('view', $vName);

		$user = JFactory::getUser();

		parent::display($cachable);

		return $this;
	}
}
