<script language="javascript"> 
<!-- 
setTimeout("cyend_redirect();",1000) 
//--> 
</script>
<?php $params = JFactory::getConfig(); ?>
<div style="text-align: center;">
<br/><br/><br/><br/>
<p>processing on site:</p>
<h2><?php echo $params->get('sitename');?></b><br/><br/></h2>
<p><img src="../media/com_spstgsrv/images/please-wait.gif" border="0" alt=""/></p>
<p>please wait...</p>
</div>
