<?php
/**
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

// no direct access
defined('_JEXEC') or die;

//import SP CYEND libraries and language
JFactory::getLanguage()->load('lib_spcyend', JPATH_SITE);
jimport('spcyend.utilities.factory');

// Include dependancies
jimport('joomla.application.component.controller');

$controller = JControllerLegacy::getInstance('SPStgSrv');
$controller->execute(JFactory::getApplication()->input->get('task'));
$controller->redirect();
