#
#<?php die('Forbidden.'); ?>
#Date: 2021-02-17 13:08:57 UTC
#Software: Joomla Platform 13.1.0 Stable [ Curiosity ] 24-Apr-2013 00:00 GMT

#Fields: datetime	priority clientip	category	message
2021-02-17T13:08:57+00:00	INFO 188.163.46.254	joomlafailure	Username and password do not match or you do not have an account yet.
2021-02-17T20:49:56+00:00	INFO 37.115.198.66	joomlacanceled	
2021-02-18T01:28:36+00:00	INFO 31.173.120.137	joomlafailure	Username and password do not match or you do not have an account yet.
2021-02-18T05:04:16+00:00	INFO 188.163.47.9	joomlafailure	Username and password do not match or you do not have an account yet.
2021-02-18T18:25:18+00:00	INFO 31.173.120.137	joomlafailure	Username and password do not match or you do not have an account yet.
2021-02-19T04:41:03+00:00	INFO 37.115.198.66	joomlacanceled	
2021-02-19T09:28:09+00:00	INFO 195.211.239.254	joomlacanceled	
2021-02-19T14:46:25+00:00	INFO 195.211.239.254	joomlacanceled	
2021-02-19T14:55:33+00:00	INFO 62.173.149.24	joomlafailure	Username and password do not match or you do not have an account yet.
2021-02-19T21:42:08+00:00	INFO 134.249.214.115	joomlacanceled	
2021-02-20T07:04:22+00:00	INFO 113.189.58.84	joomlafailure	Username and password do not match or you do not have an account yet.
2021-02-20T07:35:48+00:00	INFO 185.198.241.19	joomlacanceled	
2021-02-20T16:15:34+00:00	INFO 24.249.199.14	joomlacanceled	
2021-02-21T22:12:10+00:00	INFO 134.249.214.115	joomlacanceled	
2021-02-22T00:04:09+00:00	INFO 5.133.11.117	joomlafailure	Username and password do not match or you do not have an account yet.
2021-02-22T02:22:58+00:00	INFO 188.163.47.9	joomlafailure	Username and password do not match or you do not have an account yet.
