/*!
* @file
* @brief    boxplus: a lightweight pop-up window engine shipped with sigplus
* @author   Levente Hunyadi
* @version  1.4.2
* @remarks  Copyright (C) 2009-2010 Levente Hunyadi
* @remarks  Licensed under GNU/GPLv3, see http://www.gnu.org/licenses/gpl-3.0.html
* @see      http://hunyadi.info.hu/projects/boxplus
*/

#boxplus .boxplus-dialog {
background-color:white;
background-color:rgba(255,255,255,0.8);
color:black;
}

#boxplus .boxplus-thumbs > ul {
/*background-color:rgba(255,255,255,0.3);*/
}