/*!
* @file
* @brief    boxplus: a lightweight pop-up window engine shipped with sigplus
* @author   Levente Hunyadi
* @version  1.4.2
* @remarks  Copyright (C) 2009-2010 Levente Hunyadi
* @remarks  Licensed under GNU/GPLv3, see http://www.gnu.org/licenses/gpl-3.0.html
* @see      http://hunyadi.info.hu/projects/boxplus
*/

/* Navigation controls in viewer */
#boxplus .boxplus-viewer > .boxplus-prev {
right:0;
left:auto;
}

#boxplus .boxplus-viewer > .boxplus-prev:hover {
background-position:0 center;
}

#boxplus .boxplus-viewer > .boxplus-next {
left:0;
right:auto;
}

#boxplus .boxplus-viewer > .boxplus-next:hover {
background-position:-57px center;
}

/* Thumbnail navigation */
#boxplus .boxplus-thumbs {
direction:rtl;
}

#boxplus .boxplus-thumbs > .boxplus-rewind {
right:0;
left:auto;
background-position:0 center;
}

#boxplus .boxplus-thumbs > .boxplus-forward {
left:0;
right:auto;
background-position:-22px center;
}

/* Navigation controls under caption */
#boxplus .boxplus-caption,
#boxplus .boxplus-controls {
direction:rtl;
}

#boxplus .boxplus-controls > .boxplus-prev {
background-position:0 0;
}

#boxplus .boxplus-controls > .boxplus-next {
background-position:-22px 0;
}