DROP TABLE IF EXISTS `#__spstgsrv_backups`;
CREATE TABLE IF NOT EXISTS `#__spstgsrv_backups` (
  `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `filename` varchar(255) NOT NULL DEFAULT '',
  `mdate` int(11) NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;