if("undefined"===typeof Joomla)var Joomla={};Joomla.setcollapse=function(e,i,a){if(!document.getElementById("collapse-"+i))document.getElementById("container-collapse").innerHTML='<div class="collapse fade" id="collapse-'+i+'"><iframe class="iframe" src="'+e+'" height="'+a+'" width="100%"></iframe></div>'};if(jQuery)jQuery(document).ready(function(e){var i=function(i){var a=true,n,l=i.data("showon");e.each(l,function(i,o){$fields=e('[name="'+l[i]["field"]+'"], [name="'+l[i]["field"]+'[]"]');l[i]["valid"]=0;$fields.each(function(){if(["checkbox","radio"].indexOf(e(this).attr("type"))!=-1)n=e(this).prop("checked")?e(this).val():"";else n=e(this).val();if(!("object"===typeof n))n=JSON.parse('["'+n+'"]');for(var a in n)if(l[i]["values"].indexOf(n[a])!=-1)l[i]["valid"]=1});if(""==l[i]["op"]){if(0==l[i]["valid"])a=false}else{if("AND"==l[i]["op"]&&l[i]["valid"]+l[i-1]["valid"]<2)a=false;if("OR"==l[i]["op"]&&l[i]["valid"]+l[i-1]["valid"]>0)a=true}});a?i.slideDown():i.slideUp()};e("[data-showon]").each(function(){var a=e(this),n=e(this).data("showon");e.each(n,function(l,o){$fields=e('[name="'+n[l]["field"]+'"], [name="'+n[l]["field"]+'[]"]');$fields.each(function(){i(a)}).bind("change",function(){i(a)})})})});