<?php
// no direct access
defined('_JEXEC') or die;

class SPStgSrvTableLog extends JTable
{
	/**
	 * @param	JDatabase	A database connector object
	 */
	function __construct(&$db)
	{
		parent::__construct('#__spstgsrv_log', 'id', $db);
	}
}
