/**
* @file
* @brief    boxplus stylesheet for image slider and carousel overlay navigation
* @author   Levente Hunyadi
* @version  1.4.2
* @remarks  Copyright (C) 2009-2010 Levente Hunyadi
* @remarks  Licensed under GNU/GPLv3, see http://www.gnu.org/licenses/gpl-3.0.html
* @see      http://hunyadi.info.hu/projects/boxplus
*/

/* overlay navigation */
.boxplus-viewport > div.boxplus-prev,
.boxplus-viewport > div.boxplus-next {
position:absolute !important;
background:transparent url(transparent.gif) no-repeat scroll center center !important;
z-index:2 !important;
}

.boxplus-viewport > div.boxplus-horizontal {
top:0 !important;
height:100% !important;
}

.boxplus-viewport > div.boxplus-vertical {
left:0 !important;
width:100% !important;
}

.boxplus-viewport > div.boxplus-prev.boxplus-horizontal {
left:0 !important;
background-position:left center !important;
}

.boxplus-viewport > div.boxplus-prev.boxplus-horizontal.boxplus-large {
width:57px !important;
}

.boxplus-viewport > div.boxplus-prev.boxplus-horizontal.boxplus-large:hover {
background-image:url(btnLeftLarge.png) !important;
}

.boxplus-viewport > div.boxplus-prev.boxplus-horizontal.boxplus-small {
width:29px !important;
}

.boxplus-viewport > div.boxplus-prev.boxplus-horizontal.boxplus-small:hover {
background-image:url(btnLeftSmall.png) !important;
}

.boxplus-viewport > div.boxplus-next.boxplus-horizontal {
right:0 !important;
background-position:right center !important;
}

.boxplus-viewport > div.boxplus-next.boxplus-horizontal.boxplus-large {
width:57px !important;
}

.boxplus-viewport > div.boxplus-next.boxplus-horizontal.boxplus-large:hover {
background-image:url(btnRightLarge.png) !important;
}

.boxplus-viewport > div.boxplus-next.boxplus-horizontal.boxplus-small {
width:29px !important;
}

.boxplus-viewport > div.boxplus-next.boxplus-horizontal.boxplus-small:hover {
background-image:url(btnRightSmall.png) !important;
}

.boxplus-viewport > div.boxplus-prev.boxplus-vertical {
top:0 !important;
background-position:center top !important;
}

.boxplus-viewport > div.boxplus-prev.boxplus-vertical.boxplus-large {
height:57px !important;
}

.boxplus-viewport > div.boxplus-prev.boxplus-vertical.boxplus-large:hover {
background-image:url(btnUpLarge.png) !important;
}

.boxplus-viewport > div.boxplus-prev.boxplus-vertical.boxplus-small {
height:29px !important;
}

.boxplus-viewport > div.boxplus-prev.boxplus-vertical.boxplus-small:hover {
background-image:url(btnUpSmall.png) !important;
}

.boxplus-viewport > div.boxplus-next.boxplus-vertical {
bottom:0 !important;
background-position:center bottom !important;
}

.boxplus-viewport > div.boxplus-next.boxplus-vertical.boxplus-large {
height:57px !important;
}

.boxplus-viewport > div.boxplus-next.boxplus-vertical.boxplus-large:hover {
background-image:url(btnDownLarge.png) !important;
}

.boxplus-viewport > div.boxplus-next.boxplus-vertical.boxplus-small {
height:29px !important;
}

.boxplus-viewport > div.boxplus-next.boxplus-vertical.boxplus-small:hover {
background-image:url(btnDownSmall.png) !important;
}