<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(dirname(__FILE__));
$baseDir = dirname(dirname($vendorDir));

return array(
    'CallbackFilterIterator' => $vendorDir . '/joomla/compat/src/CallbackFilterIterator.php',
    'EasyPeasyICS' => $vendorDir . '/phpmailer/phpmailer/extras/EasyPeasyICS.php',
    'JsonSerializable' => $vendorDir . '/joomla/compat/src/JsonSerializable.php',
    'PHPMailer' => $vendorDir . '/phpmailer/phpmailer/class.phpmailer.php',
    'PHPMailerOAuth' => $vendorDir . '/phpmailer/phpmailer/class.phpmaileroauth.php',
    'PHPMailerOAuthGoogle' => $vendorDir . '/phpmailer/phpmailer/class.phpmaileroauthgoogle.php',
    'POP3' => $vendorDir . '/phpmailer/phpmailer/class.pop3.php',
    'SMTP' => $vendorDir . '/phpmailer/phpmailer/class.smtp.php',
    'lessc' => $vendorDir . '/leafo/lessphp/lessc.inc.php',
    'lessc_formatter_classic' => $vendorDir . '/leafo/lessphp/lessc.inc.php',
    'lessc_formatter_compressed' => $vendorDir . '/leafo/lessphp/lessc.inc.php',
    'lessc_formatter_lessjs' => $vendorDir . '/leafo/lessphp/lessc.inc.php',
    'lessc_parser' => $vendorDir . '/leafo/lessphp/lessc.inc.php',
    'ntlm_sasl_client_class' => $vendorDir . '/phpmailer/phpmailer/extras/ntlm_sasl_client.php',
    'phpmailerException' => $vendorDir . '/phpmailer/phpmailer/class.phpmailer.php',
);
