/**
 * @copyright	Copyright (C) 2005 - 2013 Open Source Matters, Inc. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

/**
 * Redirect
 *
 * @package		SP Staging
 * 
 * @id_arr              id arrays of the stages
 * 
 */
function cyend_redirect() {    
    var destination = window.location.href.toString();    
    destination = destination.replace('format_cyend','format');
    destination = destination.replace('task_cyend','task');
    destination = destination.replace('&view=redirect','');
    window.location = destination;
}
