<?php

// no direct access
defined('_JEXEC') or die;

jimport('joomla.application.component.controller');

class SPStgSrvControllerInstaller extends JControllerLegacy {

    public function __construct($config = array()) {
        parent::__construct($config);

        $this->registerTask('install', 'install');
    }

    public function install() {
        echo "NORMAL HTTP TASK";
        return;
    }

    public function my() {
        echo 'adsf';
    }

}

?>
