tinymce.addI18n('sw',{
"Address": "Anwani",
"Add to Dictionary": "Ongeza kwa kamusi",
"Advanced": "Hali ya juu",
"Align center": "Panga katikati",
"Align left": "Panga kushoto",
"Align right": "Panga kulia",
"Alignment": "Mpangilio",
"Alternative source": "Chanzo cha mbadala",
"Anchor": "Nanga",
"Anchors": "Mananga",
"Apply": "Omba",
"Author": "Mwandishi",
"B": "B",
"Back": "Nyuma",
"Background color": "Rangi ya usuli",
"Blockquote": "Nukuu",
"Blocks": "Matofali",
"Body": "Mwili",
"Bold": "Nene",
"Border color": "Rangi ya mpaka",
"Border": "Mipaka",
"Bottom": "Chini",
"Brightness": "Mwangaza",
"Bullet list": "Orodha ya vidato",
"Cancel": "Ghairi",
"Caption": "Maelezo mafupi",
"Cell padding": "Pedi ya kiini",
"Cell properties": "Malli ya kiini",
"Cell spacing": "Nafasi ya kiini",
"Cell type": "Aina ya kiini",
"Cell": "Mstari",
"Center": "Katikati",
"Circle": "Duara",
"Clear formatting": "Safisha fomati",
"Close": "Funga",
"Code": "Kodi",
"Color levels": "Viwango vya rangi",
"Color": "Rangi",
"Cols": "Masafu",
"Column group": "Kikundi cha safu",
"Column": "Safu",
"Constrain proportions": "Lazimisha uwiano",
"Contrast": "Tofauti ya kirangi",
"Copy": "Nakili",
"Copy row": "Nakili mstari",
"Could not find the specified string.": "Haikuweza kupata sharti lililoelezwa.",
"Crop": "Kata",
"Custom color": "Rangi ya desturi",
"Custom...": "Desturi...",
"Cut row": "Kata mstari",
"Cut": "Kata",
"Decrease indent": "Punguza jongezo",
"Default": "Difoti",
"Delete column": "Futa safu",
"Delete row": "Futa mstari",
"Delete table": "Futa jedwali",
"Description": "Fafanuo",
"Dimensions": "Kipimo",
"Disc": "Nukta",
"Div": "Div",
"Document properties": "Mali za hati",
"Edit image": "Hariri picha",
"Edit": "Hariri",
"Embed": "Embed",
"Emoticons": "Emoticons",
"Encoding": "Mwandiko",
"File": "Faili",
"Find and replace": "Pata na chukua",
"Find": "Pata",
"Finish": "Maliza",
"Flip horizontally": "Geuza usawa",
"Flip vertically": "Geuza wima",
"Font Family": "Jamii ya fonti",
"Font Sizes": "Ukubwa wa fonti",
"Footer": "Kijachini",
"Format": "Fomati",
"Formats": "Fomati",
"Fullscreen": "Skrini kamili",
"G": "G",
"Gamma": "Gamma",
"General": "Ujumla",
"H Align": "Panga H",
"Header": "Kijajuu",
"Header 1": "Kijajuu 1",
"Header 2": "Kijajuu 2",
"Header 3": "Kijajuu 3",
"Header 4": "Kijajuu 4",
"Header 5": "Kijajuu 5",
"Header 6": "Kijajuu 6",
"Header cell": "Kiini cha kijajuu",
"Headers": "Vijajuu",
"Heading 1": "Kichwa 1",
"Heading 2": "Kichwa 2",
"Heading 3": "Kichwa 3",
"Heading 4": "Kichwa 4",
"Heading 5": "Kichwa 5",
"Heading 6": "Kichwa 6",
"Headings": "Vichwa",
"Height": "Urefu",
"Horizontal line": "Mstari wa usawa",
"Horizontal space": "Nafasi ya usawa",
"Ignore all": "Puuza zote",
"Ignore": "Puuza",
"Image description": "Fafanuo la picha",
"Image options": "Machaguo ya picha",
"Increase indent": "Ongeza jongezo",
"Inline": "Inline",
"Insert": "Ingiza",
"Insert column after": "Ingiza safu baada",
"Insert column before": "Ingiza safu kabla",
"Insert date\/time": "Ingiza tarehe\/saa",
"Insert\/Edit code sample": "Ingiza\/hariri mfano wa kodi",
"Insert\/edit image": "Ingiza\/hariri picha",
"Insert\/edit link": "Ingiza\/hariri kiungo",
"Insert\/edit video": "Ingiza\/hariri video",
"Insert image": "Ingiza picha",
"Insert link": "Ingiza kiungo",
"Insert nonbreaking space": "Ingiza nafasi isiyovunjika",
"Insert row after": "Ingiza mstari baada",
"Insert row before": "Ingiza mstari kabla",
"Insert table": "Ingiza jedwali",
"Insert template": "Ingiza templeti",
"Insert Time": "Ingiza wakati",
"Insert video": "Ingiza video",
"Invert": "Weka kinyume",
"Italic": "Italiki",
"Justify": "Panga pande zote",
"Keywords": "Maneno muhimu",
"Language": "Lugha",
"Left": "Kushoto",
"Left to right": "Kushoto-kulia",
"Lower Alpha": "Herufi ndogo",
"Lower Greek": "Herufi ndogo za kigiriki",
"Lower Roman": "Herufi ndogo za kirumi",
"Match case": "Tahadhari herufi ndogo/kubwa",
"Merge cells": "Unganisha viini",
"Middle": "Katikati",
"Name": "Jina",
"New document": "Hati mpya",
"New window": "Dirisha jipya",
"Next": "Ifuatayo",
"No color": "Hakuna rangi",
"Nonbreaking space": "Nafasi isiyovunjika",
"None": "Hakuna",
"Numbered list": "Orodha ya idadi",
"Ok": "Ok",
"Orientation": "Rekebisho",
"Page break": "Mvunja wa ukurasa",
"Paragraph": "Aya",
"Paste": "Bandika",
"Paste as text": "Bandika kama maandishi",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Bandika sasa modi ya maandishi rahisi. Yaliyomo yatabandikwa kama maandishi rahisi mpaka utakapo zima chaguo hili.",
"Paste row after": "Ingiza mstari baada",
"Paste row before": "Bandika mstari kabla",
"Paste your embed code below:": "Bandika kodi yako ya embed hapo chini:",
"Poster": "Bando",
"Pre": "Iliofomatiwa",
"Preformatted": "Iliofomatiwa",
"Prev": "Iliopita",
"Preview": "Hakikisho",
"Print": "Chapa",
"R": "R",
"Redo": "Fanya tena",
"Remove link": "Ondoa kiungo",
"Replace all": "Chukua zote",
"Replace with": "Chukua na",
"Replace": "Chukua",
"Resize": "Rekebisha ukubwa",
"Restore last draft": "Regesha rasimu ya mwisho",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Eneo la maandishi tajiri. Bofya ALT-F9 kwa menyu. Bofya ALT-F10 kwa upauzana. Bofya ALT-0 kwa usaidizi.",
"Right": "Kulia",
"Right to left": "Kulia-kushoto",
"Robots": "Roboti",
"Rotate clockwise": "Zungusha kulia",
"Rotate counterclockwise": "Zungusha kushoto",
"Row": "Mstari",
"Row group": "Mstari wa kikundi",
"Row properties": "Mali ya mstari",
"Row type": "Aina ya mstari",
"Rows": "Mistari",
"Save": "Hifadhi",
"Scope": "Wigo",
"Select all": "Chagua zote",
"Sharpen": "Kunoa sawa",
"Show blocks": "Onyesha matofali",
"Show invisible characters": "Onyesha herufi isiyoonekana",
"Source code": "Kodi ya chanzo",
"Source": "Chanzo",
"Special character": "Herufi maalum",
"Spellcheck": "Ukaguzi wa maendelezo",
"Split cell": "Gawanya kiini",
"Square": "Mraba",
"Strikethrough": "Mkato",
"Style": "Mtindo",
"Subscript": "Weka chini",
"Superscript": "Weka juu",
"Table": "Jedwali",
"Table properties": "Mali ya jedwali",
"Target": "Lengo",
"Templates": "Templeti",
"Text color": "Rangi ya maandishi",
"Text to display": "Maandishi ya kuonyesha",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "URL ulioingiza unaonekana ni kama anwani ya barua pepe. Unataka kuongeza prefix inayohitajika, ambayo ni mailto: ?",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "URL ulioingiza unaonekana ni kama kiungo cha nje. Unataka kuongeza prefix inayohitajika, ambayo ni http:\/\/ ?",
"Title": "Kichwa",
"Toggle blockquote": "Washa/\zima nukuu",
"Tools": "Zana",
"Top": "Juu",
"Underline": "Pigia mstari wa chini",
"Undo": "Tengua",
"Upper Alpha": "Herufi kubwa",
"Upper Roman": "Herufi kubwa za kirumi",
"Url": "URL",
"V Align": "Panga V",
"Vertical space": "Nafasi ya wima",
"View": "Mtazamo",
"Visual aids": "Misaada ya kuona",
"Whole words": "Maneno kamili",
"Width": "Upana",
"Words: {0}": "Maneno: {0}",
"You have unsaved changes are you sure you want to navigate away?": "Uko na mabadilisho ambayo hujayahifadhi. Una hakika unataka kuwacha?",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Kisakuzi chako hakiungwi mkono kwa kupata moja kwa moja clipboard. Tafadhali tumia njia fupi ya kinanda taipu, kama Ctrl+X\/C\/V.",
"Zoom in": "Au kuvuta ndani",
"Zoom out": "Au kuvuta nje",

});