/**
* @file
* @brief    boxplus image slider stylesheet
* @author   Levente Hunyadi
* @version  1.4.2
* @remarks  Copyright (C) 2009-2010 Levente Hunyadi
* @remarks  Licensed under GNU/GPLv3, see http://www.gnu.org/licenses/gpl-3.0.html
* @see      http://hunyadi.info.hu/projects/boxplus
*/

/* image slider */
div.boxplus-slider {
margin:auto;
padding:6px;
}

div.boxplus-slider.boxplus-disabled {
position:absolute !important;
visibility:hidden !important;
}

div.boxplus-slider .boxplus-disabled {
display:none !important;
}

div.boxplus-slider img.boxplus-hidden {
visibility:hidden !important;
}

.boxplus-viewport {
margin:0 !important;
border:0 none transparent !important;
padding:0 !important;
position:relative !important;
overflow:hidden !important;
}

.boxplus-viewport > ul {
margin:0 !important;
border:0 none transparent !important;
padding:0 !important;
display:block !important;
position:absolute !important;
list-style-type:none !important;
list-style-image:none !important;
text-align:center !important;
line-height:normal;  /* override absolute value set by some responsive templates */
}

/* items on slider ribbon */
.boxplus-viewport > ul > li {
margin:0 !important;
border:0 none transparent !important;
padding:0 !important;
display:block !important;
display:table !important;  /* used for vertical centering */
position:absolute !important;
background:transparent none no-repeat scroll 0 0 !important;
border-collapse:collapse !important;
border-spacing:0 !important;
line-height:normal;  /* override absolute value set by some responsive templates */
}

.boxplus-viewport > ul > li.boxplus-loading {
background:transparent url(loading.gif) no-repeat scroll center center !important;
}

.boxplus-viewport > ul > li > img,
.boxplus-viewport > ul > li > a > img {
max-width:none;  /* override 100% set by some responsive templates */
}

.boxplus-viewport > ul > li > div,
.boxplus-viewport > ul > li > img,
.boxplus-viewport > ul > li > a {
display:block !important;
display:table-cell !important;  /* used for vertical centering */
vertical-align:middle !important;
}

/* anchor to full-size image */
.boxplus-viewport > ul > li a {
text-align:center !important;
text-decoration:none !important;
outline:none !important;
}

/* image slider outside navigation */
.boxplus-paging {
position:relative !important;
text-align:center !important;
}

.boxplus-paging > div {
position:absolute !important;
top:0 !important;
}

.boxplus-paging > div.boxplus-prev,
.boxplus-paging > div.boxplus-next {
width:8px !important;
height:13px !important;
}

.boxplus-paging > div.boxplus-first,
.boxplus-paging > div.boxplus-last {
width:11px !important;
height:13px !important;
}

.boxplus-paging > div.boxplus-first {
background:url(paging.png) 0px 0px !important;
left:0 !important;
}

.boxplus-paging > div.boxplus-prev {
background:url(paging.png) -11px 0px !important;
left:16px !important;
}

.boxplus-paging > div.boxplus-next {
background:url(paging.png) -19px 0px !important;
right:16px !important;
}

.boxplus-paging > div.boxplus-last {
background:url(paging.png) -27px 0px !important;
right:0 !important;
}

.boxplus-paging > div.boxplus-first:hover {
background-position:0px -14px !important;
}

.boxplus-paging > div.boxplus-prev:hover {
background-position:-11px -14px !important;
}

.boxplus-paging > div.boxplus-next:hover {
background-position:-19px -14px !important;
}

.boxplus-paging > div.boxplus-last:hover {
background-position:-27px -14px !important;
}