<?php

/**
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */
// No direct access
defined('_JEXEC') or die;

jimport('joomla.application.component.view');

$version = SpStgSrvHelper::getVersion();
        switch ($version) {
            case 2:
                include_once 'view.html_v2.php';
                class SPStgSrvViewLog extends SPStgSrvViewLog_v2{
                    public function display($tpl = null) {
                        $tpl = 'v2';
                        parent::display($tpl);
                    }
                }
                break;
            case 3:
                include_once 'view.html_v3.php';
                class SPStgSrvViewLog extends SPStgSrvViewLog_v3{
                    public function display($tpl = null) {
                        $tpl = 'v3';
                        parent::display($tpl);
                    }
                }
                break;

            default:
                return FALSE;
        }
        

