<?php
/**
 * @package     Joomla.Administrator
 * @subpackage  com_users
 *
 * @copyright   Copyright (C) 2005 - 2016 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

require_once JPATH_SITE . '/components/com_users/controllers/profile_base_json.php';

/**
 * Profile controller class for Users.
 *
 * @since  3.5
 */
class UsersControllerProfile extends UsersControllerProfile_Base_Json
{
}
