<?php
defined('_JEXEC') or die;

if (!defined('DS')) define('DS','/');

$app = JFactory::getApplication();
$templateparams = $app->getTemplate(true)->params;
JHtml::addIncludePath(JPATH_COMPONENT.DS.'helpers');

// Create shortcut to parameters.
$params		= $this->item->params;
$canEdit	= $this->item->params->get('access-edit');

?>

<div id="page">

<?php if ($this->params->get('show_page_heading', 1)) : ?>
<h1 class="componentheading"><span><?php echo $this->escape($this->params->get('page_heading')); ?></span></h1><br class="both" />
<?php endif; ?>

<?php if (($this->params->get('show_title')) || ($this->params->get('show_pdf_icon')) || ($this->params->get('show_print_icon')) || ($this->params->get('show_email_icon')) || ($this->params->get('show_create_date'))  ) : ?>
<div class="content-header">


<?php if ($params->get('show_title')|| $params->get('access-edit')) : ?>
<h1 class="contentheading"><?php if ($params->get('link_titles') && !empty($this->item->readmore_link)) : ?><a href="<?php echo $this->item->readmore_link; ?>"><?php echo $this->escape($this->item->title); ?></a>
<?php else : ?><?php echo $this->escape($this->item->title); ?><?php endif; ?>
</h1>
<?php endif; ?>

<?php if ($canEdit ||  $params->get('show_print_icon') || $params->get('show_email_icon')) : ?>
		<ul class="actions">
		<?php if (!$this->print) : ?>
				<?php if ($params->get('show_print_icon')) : ?>
				<li class="print-icon">
						<?php echo JHtml::_('icon.print_popup',  $this->item, $params); ?>
				</li>
				<?php endif; ?>

				<?php if ($params->get('show_email_icon')) : ?>
				<li class="email-icon">
						<?php echo JHtml::_('icon.email',  $this->item, $params); ?>
				</li>
				<?php endif; ?>
				<?php if ($canEdit) : ?>
						<li class="edit-icon">
							<?php echo JHtml::_('icon.edit', $this->item, $params); ?>
						</li>
					<?php endif; ?>
		<?php else : ?>
				<li>
						<?php echo JHtml::_('icon.print_screen',  $this->item, $params); ?>
				</li>
		<?php endif; ?>
		</ul>
<?php endif; ?>


	<?php if ($params->get('show_create_date')) : ?>
	<span class="createdate">
		<?php echo JText::sprintf('COM_CONTENT_CREATED_DATE_ON', JHTML::_('date',$this->item->created, JText::_('DATE_FORMAT_LC2'))); ?>
	</span>
	<?php endif; ?>

	<?php if ($params->get('show_publish_date')) : ?>
	<span class="createdate">
		<?php echo JText::sprintf('COM_CONTENT_PUBLISHED_DATE', JHTML::_('date',$this->item->publish_up, JText::_('DATE_FORMAT_LC2'))); ?>
	</span>
	<?php endif; ?>
	
	<?php if ($params->get('show_hits')) : ?>
	<span class="hits">
		<?php echo JText::sprintf('COM_CONTENT_ARTICLE_HITS', $this->item->hits); ?>
	</span>
	<?php endif; ?>
	
<div class="both"><!-- --></div>
</div>
<?php endif; ?>

<?php if ( ($params->get('show_parent_category') && $this->item->parent_slug != '1:root') || ($params->get('show_category')) ) : ?>
<div class="article-adds">
<p class="art-nfo">

<?php if ($params->get('show_parent_category') && $this->item->parent_slug != '1:root') : ?>
		<span>
			<?php	$title = $this->escape($this->item->parent_title);
					$url = '<a href="'.JRoute::_(ContentHelperRoute::getCategoryRoute($this->item->parent_slug)).'">'.$title.'</a>';?>
			<?php if ($params->get('link_parent_category') AND $this->item->parent_slug) : ?>
				<?php echo JText::sprintf('COM_CONTENT_PARENT', $url); ?>
				<?php else : ?>
				<?php echo JText::sprintf('COM_CONTENT_PARENT', $title); ?>
			<?php endif; ?>
			
			<?php if ($params->get('show_category')) : ?>
				<?php echo ' - '; ?>
			<?php endif; ?>
			
		<span>
<?php endif; ?>
<?php if ($params->get('show_category')) : ?>
		<span>
			<?php 	$title = $this->escape($this->item->category_title);
					$url = '<a href="'.JRoute::_(ContentHelperRoute::getCategoryRoute($this->item->catslug)).'">'.$title.'</a>';?>
			<?php if ($params->get('link_category') AND $this->item->catslug) : ?>
				<?php echo JText::sprintf('COM_CONTENT_CATEGORY', $url); ?>
				<?php else : ?>
				<?php echo JText::sprintf('COM_CONTENT_CATEGORY', $title); ?>
			<?php endif; ?>
		<span>
<?php endif; ?>

</p>

<div class="both"><!-- --></div>
</div>
<?php endif; ?>
<div class="main-content-item">


<?php  if (!$params->get('show_intro')) :
	echo $this->item->event->afterDisplayTitle;
endif; ?>

<?php echo $this->item->event->beforeDisplayContent; ?>

<?php if (isset ($this->item->toc)) : ?>
	<?php echo $this->item->toc; ?>
<?php endif; ?>

<?php echo $this->item->text; ?>

<?php echo $this->item->event->afterDisplayContent; ?>


<div class="both"><!-- --></div>
<?php if( ($params->get('show_author') && !empty($this->item->author )) || ($params->get('show_modify_date')) ): ?>
<p class="article-footer">
	
<?php if ($params->get('show_author') && !empty($this->item->author )) : ?>
	<span class="createdby"> 
		<?php $author =  $this->item->author; ?>
		<?php $author = ($this->item->created_by_alias ? $this->item->created_by_alias : $author);?>

			<?php if (!empty($this->item->contactid ) &&  $params->get('link_author') == true):?>
				<?php 	echo JText::sprintf('COM_CONTENT_WRITTEN_BY' , 
				 JHTML::_('link',JRoute::_('index.php?option=com_contact&view=contact&id='.$this->item->contactid),$author)); ?>

			<?php else :?>
				<?php echo JText::sprintf('COM_CONTENT_WRITTEN_BY', $author); ?>
			<?php endif; ?>
	</span>
<?php endif; ?>	


<?php if ($params->get('show_modify_date')) : ?>
	<span class="modifydate">
	<?php echo JText::sprintf('COM_CONTENT_LAST_UPDATED', JHTML::_('date',$this->item->modified, JText::_('DATE_FORMAT_LC2'))); ?>
	</span>
<?php endif; ?>

</p>
<?php endif; ?>	
</div>

</div>
