/*!
* @file
* @brief    boxplus: a lightweight pop-up window engine shipped with sigplus
* @author   Levente Hunyadi
* @version  1.4.2
* @remarks  Copyright (C) 2009-2010 Levente Hunyadi
* @remarks  Licensed under GNU/GPLv3, see http://www.gnu.org/licenses/gpl-3.0.html
* @see      http://hunyadi.info.hu/projects/boxplus
*/

#boxplus .boxplus-dialog .boxplus-progress {
left:50%;
top:50%;
margin-left:-16px;
margin-top:-16px;
}

#boxplus .boxplus-controls > * {
float:left;
}

#boxplus .boxplus-controls.boxplus-left > * {
float:left;
}

#boxplus .boxplus-controls.boxplus-right > * {
float:right;
}

#boxplus .boxplus-caption {
clear:both;
}

#boxplus .boxplus-thumbs > ul {
display:block;
}

#boxplus .boxplus-thumbs > ul > li {
display:inline;
}