/*!
* @file
* @brief    boxplus: a lightweight pop-up window engine shipped with sigplus
* @author   Levente Hunyadi
* @version  1.4.2
* @remarks  Copyright (C) 2009-2010 Levente Hunyadi
* @remarks  Licensed under GNU/GPLv3, see http://www.gnu.org/licenses/gpl-3.0.html
* @see      http://hunyadi.info.hu/projects/boxplus
*/

#boxplus .boxplus-dialog {
padding:0 !important;
background-color:rgba(0, 0, 0, 0.5);
margin:30px 0 0 0;
border-radius:20px;
-moz-border-radius:20px;
-webkit-border-radius:20px;
}

#boxplus .boxplus-title {
display:none;
}

#boxplus .boxplus-dialog > .boxplus-title {
display:block;
color:white;
height:24px;
margin:-30px 0 0 20px;
font-weight:normal;
font-size:20px;
line-height:24px;
overflow:hidden;
}

#boxplus .boxplus-dialog .boxplus-main {  /* increase precedence with multiple qualifiers */
margin:10px;
padding:20px;
}

#boxplus .boxplus-dialog .boxplus-sideways {
right:20px;
top:20px;
bottom:20px;
}

#boxplus .boxplus-dialog .boxplus-m {
position:absolute;
top:10px;
bottom:10px;
left:10px;
right:10px;
z-index:-1;
background-color:white !important;
border-radius:10px;
-moz-border-radius:10px;
-webkit-border-radius:10px;
}
