<?php

/*
 * Copyright (C) 2017 KAINOTOMO PH LTD <info@kainotomo.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Joomla\Component\SpStgSrv\Administrator\Controller;

defined('_JEXEC') or die;

use Joomla\CMS\MVC\Controller\BaseController;
use Joomla\CMS\Factory;
use Joomla\Component\SpStgSrv\Administrator\Helper\SpStgSrvHelper;

/**
 * Component Controller
 *
 * @since  1.5
 */
class DisplayController extends BaseController {

        /**
         * The default view.
         *
         * @var    string
         * @since  1.6
         */
        protected $default_view = 'log';

        public function display($cachable = false, $urlparams = array()) {

		// Get the document object.
		$document = Factory::getDocument();

		// Set the default view name and format from the Request.
		$vName		= Factory::getApplication()->input->getCmd('view', 'log');
		$vFormat	= $document->getType();
		$lName		= Factory::getApplication()->input->getCmd('layout', 'default');
                
                return parent::display();
        }

}
