<?php defined( '_JEXEC' ) or die;
	$columns_position = $this->params->get("cols");
	$h1_title   = $this->params->get("H1Title"); 
	$h2_title	= $this->params->get("H2Title");
	$default_font = "default";
	$template_path = $this->baseurl.'/templates/'.$this->template; // template path
?>
