<?php defined('_JEXEC') or die; 

if (!defined('DS')) define('DS','/');

define( 'YOURBASEPATH', dirname(__FILE__) ); ?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" 

"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">

<?php JHTML::_('behavior.framework', true); ?>

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo $this->language; ?>" lang="<?php echo $this->language; ?>" >

<head>

<jdoc:include type="head" />

<link href="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template ?>/css/template.css" rel="stylesheet" type="text/css" media="all" />

<?php

  require(YOURBASEPATH .DS."/config.php");

  require(YOURBASEPATH .DS."/utils/bss_fontchanger.php");

?>

<!--[if lte IE 6]>

<script defer type="text/javascript" src="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template ?>/js/pngfix.js"></script>

<![endif]-->

<?php if($this->params->get('dropdownenabled')) : ?>

<!--[if lte IE 7]>

<script type="text/javascript">

iehover = function() { var sfEls = document.getElementById("menu").getElementsByTagName("li");

for (var i=0; i<sfEls.length; i++) { sfEls[i].onmouseover=function() { this.className+=" iehover"; } 

sfEls[i].onmouseout=function() { this.className=this.className.replace(new RegExp(" iehover\\b"), ""); }

} }

if (window.attachEvent) window.attachEvent("onload", iehover);

</script>

<![endif]--> 

<?php endif; ?>

<style type="text/css">

#top-handler h1{left:<?php echo $this->params->get('H1TitlePositionX'); ?>px;top:<?php echo $this->params->get('H1TitlePositionY'); ?>px;}#top-handler h2{left:<?php echo $this->params->get('H2TitlePositionX'); ?>px;top:<?php echo $this->params->get('H2TitlePositionY'); ?>px;}#top-handler #logo{left:<?php echo $this->params->get('logoPositionX'); ?>px;top:<?php echo $this->params->get('logoPositionY'); ?>px;}

body,.button,button{<?php

switch ($this->params->get('fontface')) {

  case "a": echo "font-family:Arial, Helvetica, sans-serif;"; break;

  case "b": echo "font-family:Verdana,Geneva,Arial,Helvetica,sans-serif;"; break;

  case "c": echo "font-family:Tahoma,Arial,Helvetica,sans-serif;"; break;

  case "d": echo "font-family:Lucida Sans Unicode,Helvetica,sans-serif;"; break;

  case "e": echo "font-family:\"Times New Roman\",Times,serif;"; break;

  case "f": echo "font-family:Georgia,\"Times New Roman\",Times,serif;"; break;

  case "g": echo "font-family:Trebuchet MS,\"Times New Roman\",Times,serif;"; break;

} ?>}

<?php if($this->countModules('user-position-1 and user-position-2 and user-position-3')) : ?>#top-modules .top-module{width:300px;}

<?php elseif($this->countModules('user-position-1 and user-position-2') || $this->countModules('user-position-1 and user-position-3') || $this->countModules('user-position-2 and user-position-3') ) : ?>#top-modules .top-module{width:460px;}

<?php elseif($this->countModules('user-position-1 or user-position-2 or user-position-3')) : ?>#top-modules .top-module{width:97%;}<?php endif; ?>



<?php if($this->countModules('user-position-4 and user-position-5 and user-position-6')) : ?>#bot-modules .bot-module{width:300px;}

<?php elseif($this->countModules('user-position-4 and user-position-5') || $this->countModules('user-position-4 and user-position-6') || $this->countModules('user-position-5 and user-position-6') ) : ?>#bot-modules .bot-module{width:460px;}

<?php elseif($this->countModules('user-position-4 or user-position-5 or user-position-6')) : ?>#bot-modules .bot-module{width:97%;}<?php endif; ?>



<?php if($columns_position == 'lr') { ?>#col-left{float:left;}#col-center{float:right;padding-left:10px;}<?php } elseif($columns_position == 'rl') { ?>#col-left{float:right;}#col-center{float:left;padding-right:10px;}<?php } ?> 



</style>

<?php if($this->countModules('slideshow')) : ?>

<script type="text/javascript" src="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template ?>/js/slideshow.js"></script>

<link href="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template ?>/css/slideshow.css" rel="stylesheet" type="text/css" media="screen" />

<style type="text/css">

.slideshow-images,.slideshow {height: <?php echo $this->params->get('slideheight'); ?>px;width: <?php echo $this->params->get('slidewidth'); ?>px;}</style>

<?php endif; ?>

</head>

<body class="<?php echo $fontstyle; ?> background">



<div id="site-handler">

  <div id="top-line" class="site-width">

    <?php if( $this->params->get('fontTools') || $this->params->get('twitter') || $this->params->get('RSS') || $this->params->get('facebook') ) : ?>

    <ul id="top-navigation-links"><?php if($this->params->get('fontTools')) : ?>

      <li>Font size:</li>

      <li><a href="<?php echo $thisurl; ?>fontstyle=f-smaller" title="Decrease size" id="minus">Decrease</a></li>

      <li><a href="<?php echo $thisurl; ?>fontstyle=f-larger" title="Increase size" id="plus">Increase</a></li>

      <li><a href="<?php echo $thisurl; ?>fontstyle=f-default" title="Reset font to default" id="reset">Reset</a></li><?php endif; ?>

      <?php if($this->params->get('twitter')) : ?><li><a href="<?php echo $this->params->get('twitter'); ?>" title="Twitter" id="twitter">Follow Us</a></li><?php endif; ?>

      <?php if($this->params->get('facebook')) : ?><li><a href="<?php echo $this->params->get('facebook'); ?>" title="Facebook" id="facebook">Facebook</a></li><?php endif; ?>

      <?php if($this->params->get('RSS')) : ?><li><a href="<?php echo $this->params->get('RSS'); ?>" title="RSS" id="rss">RSS</a></li><?php endif; ?>

    </ul>

    <?php endif; ?>

  </div>

  <div id="top-handler" class="site-width">
	<div class="socialicons">
    	<div class="sicon"><a href="https://www.facebook.com/pages/A-Plus-Contracting/775257639161931" target="_blank"><img src="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template ?>/images/facebook_icon.png" alt="facebook" /></a></div>
        <div class="sicon"><a href="https://twitter.com/apluscont" target="_blank"><img src="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template ?>/images/twitter_icon.png" alt="twitter" /></a></div>
        <div class="sicon"><a href="https://plus.google.com/109506785924379309033" target="_blank"><img src="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template ?>/images/gplus_icon.png" alt="google plus" /></a></div>
        <div style="clear:both"></div>
    </div>
    

    <?php if($this->params->get('logoLinked')) : ?>

      <?php if($this->params->get('H1TitleImgText') == 1) : ?>

        <h1><a href="<?php echo $this->baseurl; ?>">

          <img alt="<?php echo $h1_title; ?>" src="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template ?>/images/logo/<?php echo $this->params->get("H1Titleimage"); ?>" /></a>

        </h1>

      <?php else : ?>

        <h1><a href="<?php echo $this->baseurl; ?>"><?php echo $h1_title; ?></a></h1>

      <?php endif; ?>

      

    <?php else : ?>

      <?php if($this->params->get('H1TitleImgText') == 1) : ?>

        <h1>

          <img alt="<?php echo $h1_title; ?>" src="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template ?>/images/logo/<?php echo $this->params->get("H1Titleimage"); ?>" /></a>

        </h1>

      <?php else : ?>

        <h1><?php echo $h1_title; ?></h1>

      <?php endif; ?>

    <?php endif; ?>  



    <?php if($this->params->get('H2TitleImgText') == 1) : ?>

      <h2>

        <img alt="<?php echo $h2_title; ?>" src="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template ?>/images/logo/<?php echo $this->params->get("H2Titleimage"); ?>" />

      </h2>

    <?php else : ?>

      <h2><?php echo $h2_title; ?></h2>

    <?php endif; ?>

    

    <?php if($this->params->get('logoimg') && $this->params->get('logoimg')!=-1 ) : ?>

    <img id="logo" src="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template ?>/images/logo/<?php echo $this->params->get("logoimg"); ?>" />

    <?php endif; ?>

    

  </div>

  <div id="top-nav-handler" class="site-width">

    <div id="menu"><jdoc:include type="modules" name="position-1" /></div>

    <div id="search"><jdoc:include type="modules" name="position-0" /></div>

    <div class="both"></div>

  </div>

  

  <?php if($this->countModules('slideshow')) : ?>  

  <div id="slideshow-handler" class="site-width">

    <script type="text/javascript">    

    //<![CDATA[

      window.addEvent('domready', function(){

      var myShow = new Slideshow('show', [<?php echo $this->params->get('slidebody'); ?>], {

        controller: false, 

        height: <?php echo $this->params->get('slideheight'); ?>, 

        loader: false, 

        delay: <?php echo $this->params->get('slidetime'); ?>, 

        duration: <?php echo $this->params->get('durationeffect'); ?>, 

        hu: '<?php echo $this->baseurl; ?>/templates/<?php echo $this->template ?>/images/slideshow/', 

        thumbnails: false, 

        width: <?php echo $this->params->get('slidewidth'); ?>});

      });

    //]]>

    </script>

    <div id="show" class="slideshow">

      <img src="<?php echo $this->baseurl; ?>/templates/<?php echo $this->template ?>/images/slideshow/slide-1.jpg" width="<?php echo $this->params->get('slidewidth'); ?>" height="<?php echo $this->params->get('slideheight'); ?>" alt="1" />

    </div>

  </div>

  <?php endif; ?>

    

  <?php if($this->countModules('user-position-1 or user-position-2 or user-position-3')) : ?>  

  <div id="top-modules" class="site-width">

    <div class="top-module"><jdoc:include type="modules" name="user-position-1" style="joomladesignsMod" headerLevel="3" /></div>

    <div class="top-module"><jdoc:include type="modules" name="user-position-2" style="joomladesignsMod" headerLevel="3" /></div>

    <div class="top-module"><jdoc:include type="modules" name="user-position-3" style="joomladesignsMod" headerLevel="3" /></div>

    <div class="both"><!-- --></div>

  </div>

  <?php endif; ?>

  



  <div class="site-width">

    <div id="middle-cols">

      <?php if($this->countModules('position-7')) : ?>

      <div id="col-left">

        <jdoc:include type="modules" name="position-7" style="joomladesignsMod" headerLevel="3" />

      </div>

      <?php endif;?>

      <div id="col-center" class="<?php if($this->countModules('position-7')) : ?>s600<?php else: ?>s920<?php endif; ?>">

        <div id="content-main">

          <div id="jcom-content"><jdoc:include type="message" /><jdoc:include type="component" /><div class="both"><!-- --></div></div>

        </div>      

      </div>

      <div class="both"><!-- --></div>

    </div>

  </div>

</div>

<?php if($this->countModules('user-position-4 or user-position-5 or user-position-6')) : ?>

<div id="bot-modules">

  <div class="site-width">

    <div class="bot-module"><jdoc:include type="modules" name="user-position-4" style="joomladesignsMod" headerLevel="3" /></div>

    <div class="bot-module"><jdoc:include type="modules" name="user-position-5" style="joomladesignsMod" headerLevel="3" /></div>

    <div class="bot-module"><jdoc:include type="modules" name="user-position-6" style="joomladesignsMod" headerLevel="3" />

      

    </div>

    <div class="both"><!-- --></div>

  </div>

  

</div>

  

<?php endif; ?>

<div id="seo"><small>A Plus Contracting - Specialising in Excavator & Bobcat Hire, Poly Welding, Mines Rehabilitation and all Silt Fencing & traffic management, traffic control, 

  <br />traffic control plans and mobile variable message boards in Newcastle, Hunter Valley & the Central Coast NSW. <br />

  &nbsp;| &nbsp;Copyright &copy; All Rights Reserved.&nbsp;  A Plus Contracting

    <a href="http://www.websiteguy.com.au" target="_blank">Central Coast, Newcastle &amp; Sydney Website Designers - Website Guy</a><a href="login" target="_self">.</a></small></div>



<br />

<jdoc:include type="modules" name="debug" />

</body>

</html>